This repository contains a client library for LaunchDarkly's REST API. This client was automatically
generated from our [OpenAPI specification](https://app.launchdarkly.com/api/v2/openapi.json) using a [code generation library](https://github.com/launchdarkly/ld-openapi). View our [sample code](#sample-code) for example usage.

This REST API is for custom integrations, data export, or automating your feature flag workflows. *DO NOT* use this client library to include feature flags in your web or mobile application. To integrate feature flags with your application, read the [SDK documentation](https://docs.launchdarkly.com/sdk).
# launchdarkly_api

LaunchDarklyApi - the Ruby gem for the LaunchDarkly REST API

# Authentication  All REST API resources are authenticated with either [personal or service access tokens](https://docs.launchdarkly.com/home/account-security/api-access-tokens), or session cookies. Other authentication mechanisms are not supported. You can manage personal access tokens on your [Account settings](https://app.launchdarkly.com/settings/tokens) page.  LaunchDarkly also has SDK keys, mobile keys, and client-side IDs that are used by our server-side SDKs, mobile SDKs, and client-side SDKs, respectively. **These keys cannot be used to access our REST API**. These keys are environment-specific, and can only perform read-only operations (fetching feature flag settings).  | Auth mechanism                                                                                  | Allowed resources                                                                                     | Use cases                                          | | ----------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------- | -------------------------------------------------- | | [Personal access tokens](https://docs.launchdarkly.com/home/account-security/api-access-tokens) | Can be customized on a per-token basis                                                                | Building scripts, custom integrations, data export | | SDK keys                                                                                        | Can only access read-only SDK-specific resources and the firehose, restricted to a single environment | Server-side SDKs, Firehose API                     | | Mobile keys                                                                                     | Can only access read-only mobile SDK-specific resources, restricted to a single environment           | Mobile SDKs                                        | | Client-side ID                                                                                  | Single environment, only flags marked available to client-side                                        | Client-side JavaScript                             |  > ### Keep your access tokens and SDK keys private > > Access tokens should _never_ be exposed in untrusted contexts. Never put an access token in client-side JavaScript, or embed it in a mobile application. LaunchDarkly has special mobile keys that you can embed in mobile apps. If you accidentally expose an access token or SDK key, you can reset it from your [Account Settings](https://app.launchdarkly.com/settings#/tokens) page. > > The client-side ID is safe to embed in untrusted contexts. It's designed for use in client-side JavaScript.  ## Via request header  The preferred way to authenticate with the API is by adding an `Authorization` header containing your access token to your requests. The value of the `Authorization` header must be your access token.  Manage personal access tokens from the [Account Settings](https://app.launchdarkly.com/settings/tokens) page.  ## Via session cookie  For testing purposes, you can make API calls directly from your web browser. If you're logged in to the application, the API will use your existing session to authenticate calls.  If you have a [role](https://docs.launchdarkly.com/home/team/built-in-roles) other than Admin, or have a [custom role](https://docs.launchdarkly.com/home/team/custom-roles) defined, you may not have permission to perform some API calls. You will receive a `401` response code in that case.  > ### Modifying the Origin header causes an error > > LaunchDarkly validates that the Origin header for any API request authenticated by a session cookie matches the expected Origin header. The expected Origin header is `https://app.launchdarkly.com`. > > If the Origin header does not match what's expected, LaunchDarkly returns an error. This error can prevent the LaunchDarkly app from working correctly. > > Any browser extension that intentionally changes the Origin header can cause this problem. For example, the `Allow-Control-Allow-Origin: *` Chrome extension changes the Origin header to `http://evil.com` and causes the app to fail. > > To prevent this error, do not modify your Origin header. > > LaunchDarkly does not require origin matching when authenticating with an access token, so this issue does not affect normal API usage.  # Representations  All resources expect and return JSON response bodies. Error responses will also send a JSON body. Read [Errors](#section/Errors) for a more detailed description of the error format used by the API.  In practice this means that you always get a response with a `Content-Type` header set to `application/json`.  In addition, request bodies for `PUT`, `POST`, `REPORT` and `PATCH` requests must be encoded as JSON with a `Content-Type` header set to `application/json`.  ## Summary and detailed representations  When you fetch a list of resources, the response includes only the most important attributes of each resource. This is a _summary representation_ of the resource. When you fetch an individual resource (for example, a single feature flag), you receive a _detailed representation_ containing all of the attributes of the resource.  The best way to find a detailed representation is to follow links. Every summary representation includes a link to its detailed representation.  ## Links and addressability  The best way to navigate the API is by following links. These are attributes in representations that link to other resources. The API always uses the same format for links:  - Links to other resources within the API are encapsulated in a `_links` object. - If the resource has a corresponding link to HTML content on the site, it is stored in a special `_site` link.  Each link has two attributes: an href (the URL) and a type (the content type). For example, a feature resource might return the following:  ```json {   \"_links\": {     \"parent\": {       \"href\": \"/api/features\",       \"type\": \"application/json\"     },     \"self\": {       \"href\": \"/api/features/sort.order\",       \"type\": \"application/json\"     }   },   \"_site\": {     \"href\": \"/features/sort.order\",     \"type\": \"text/html\"   } } ```  From this, you can navigate to the parent collection of features by following the `parent` link, or navigate to the site page for the feature by following the `_site` link.  Collections are always represented as a JSON object with an `items` attribute containing an array of representations. Like all other representations, collections have `_links` defined at the top level.  Paginated collections include `first`, `last`, `next`, and `prev` links containing a URL with the respective set of elements in the collection.  # Updates  Resources that accept partial updates use the `PATCH` verb, and support the [JSON Patch](http://tools.ietf.org/html/rfc6902) format. Some resources also support the [JSON Merge Patch](https://tools.ietf.org/html/rfc7386) format. In addition, some resources support optional comments that can be submitted with updates. Comments appear in outgoing webhooks, the audit log, and other integrations.  ## Updates via JSON Patch  [JSON Patch](http://tools.ietf.org/html/rfc6902) is a way to specify the modifications to perform on a resource. For example, in this feature flag representation:  ```json {     \"name\": \"New recommendations engine\",     \"key\": \"engine.enable\",     \"description\": \"This is the description\",     ... } ```  You can change the feature flag's description with the following patch document:  ```json [{ \"op\": \"replace\", \"path\": \"/description\", \"value\": \"This is the new description\" }] ```  JSON Patch documents are always arrays. You can specify multiple modifications to perform in a single request. You can also test that certain preconditions are met before applying the patch:  ```json [   { \"op\": \"test\", \"path\": \"/version\", \"value\": 10 },   { \"op\": \"replace\", \"path\": \"/description\", \"value\": \"The new description\" } ] ```  The above patch request tests whether the feature flag's `version` is `10`, and if so, changes the feature flag's description.  Attributes that aren't editable, like a resource's `_links`, have names that start with an underscore.  ## Updates via JSON Merge Patch  The API also supports the [JSON Merge Patch](https://tools.ietf.org/html/rfc7386) format, as well as the [Update feature flag](/tag/Feature-flags#operation/patchFeatureFlag) resource.  JSON Merge Patch is less expressive than JSON Patch but in many cases, it is simpler to construct a merge patch document. For example, you can change a feature flag's description with the following merge patch document:  ```json {   \"description\": \"New flag description\" } ```  ## Updates with comments  You can submit optional comments with `PATCH` changes. The [Update feature flag](/tag/Feature-flags#operation/patchFeatureFlag) resource supports comments.  To submit a comment along with a JSON Patch document, use the following format:  ```json {   \"comment\": \"This is a comment string\",   \"patch\": [{ \"op\": \"replace\", \"path\": \"/description\", \"value\": \"The new description\" }] } ```  To submit a comment along with a JSON Merge Patch document, use the following format:  ```json {   \"comment\": \"This is a comment string\",   \"merge\": { \"description\": \"New flag description\" } } ```  ## Updates via semantic patches  The API also supports the Semantic patch format. A semantic `PATCH` is a way to specify the modifications to perform on a resource as a set of executable instructions.  JSON Patch uses paths and a limited set of operations to describe how to transform the current state of the resource into a new state. Semantic patch allows you to be explicit about intent using precise, custom instructions. In many cases, semantic patch instructions can also be defined independently of the current state of the resource. This can be useful when defining a change that may be applied at a future date.  For example, in this feature flag configuration in environment Production:  ```json {     \"name\": \"Alternate sort order\",     \"kind\": \"boolean\",     \"key\": \"sort.order\",    ...     \"environments\": {         \"production\": {             \"on\": true,             \"archived\": false,             \"salt\": \"c29ydC5vcmRlcg==\",             \"sel\": \"8de1085cb7354b0ab41c0e778376dfd3\",             \"lastModified\": 1469131558260,             \"version\": 81,             \"targets\": [                 {                     \"values\": [                         \"Gerhard.Little@yahoo.com\"                     ],                     \"variation\": 0                 },                 {                     \"values\": [                         \"1461797806429-33-861961230\",                         \"438580d8-02ee-418d-9eec-0085cab2bdf0\"                     ],                     \"variation\": 1                 }             ],             \"rules\": [],             \"fallthrough\": {                 \"variation\": 0             },             \"offVariation\": 1,             \"prerequisites\": [],             \"_site\": {                 \"href\": \"/default/production/features/sort.order\",                 \"type\": \"text/html\"             }        }     } } ```  You can add a date you want a user to be removed from the feature flag's user targets. For example, “remove user 1461797806429-33-861961230 from the user target for variation 0 on the Alternate sort order flag in the production environment on Wed Jul 08 2020 at 15:27:41 pm”. This is done using the following:  ```json {   \"comment\": \"update expiring user targets\",   \"instructions\": [     {       \"kind\": \"removeExpireUserTargetDate\",       \"userKey\": \"userKey\",       \"variationId\": \"978d53f9-7fe3-4a63-992d-97bcb4535dc8\"     },     {       \"kind\": \"updateExpireUserTargetDate\",       \"userKey\": \"userKey2\",       \"variationId\": \"978d53f9-7fe3-4a63-992d-97bcb4535dc8\",       \"value\": 1587582000000     },     {       \"kind\": \"addExpireUserTargetDate\",       \"userKey\": \"userKey3\",       \"variationId\": \"978d53f9-7fe3-4a63-992d-97bcb4535dc8\",       \"value\": 1594247266386     }   ] } ```  Here is another example. In this feature flag configuration:  ```json {   \"name\": \"New recommendations engine\",   \"key\": \"engine.enable\",   \"environments\": {     \"test\": {       \"on\": true     }   } } ```  You can change the feature flag's description with the following patch document as a set of executable instructions. For example, “add user X to targets for variation Y and remove user A from targets for variation B for test flag”:  ```json {   \"comment\": \"\",   \"instructions\": [     {       \"kind\": \"removeUserTargets\",       \"values\": [\"438580d8-02ee-418d-9eec-0085cab2bdf0\"],       \"variationId\": \"852cb784-54ff-46b9-8c35-5498d2e4f270\"     },     {       \"kind\": \"addUserTargets\",       \"values\": [\"438580d8-02ee-418d-9eec-0085cab2bdf0\"],       \"variationId\": \"1bb18465-33b6-49aa-a3bd-eeb6650b33ad\"     }   ] } ```  > ### Supported semantic patch API endpoints > > - [Update feature flag](/tag/Feature-flags#operation/patchFeatureFlag) > - [Update expiring user targets on feature flag](/tag/Feature-flags#operation/patchExpiringUserTargets) > - [Update expiring user target for flags](/tag/User-Settings#operation/patchExpiringFlagsForUser) > - [Update expiring user targets on segment](/tag/Segments#operation/patchExpiringUserTargetsOnSegment)  # Errors  The API always returns errors in a common format. Here's an example:  ```json {   \"code\": \"invalid_request\",   \"message\": \"A feature with that key already exists\",   \"id\": \"30ce6058-87da-11e4-b116-123b93f75cba\" } ```  The general class of error is indicated by the `code`. The `message` is a human-readable explanation of what went wrong. The `id` is a unique identifier. Use it when you're working with LaunchDarkly support to debug a problem with a specific API call.  ## HTTP Status - Error Response Codes  | Code | Definition        | Desc.                                                                                       | Possible Solution                                                | | ---- | ----------------- | ------------------------------------------------------------------------------------------- | ---------------------------------------------------------------- | | 400  | Bad Request       | A request that fails may return this HTTP response code.                                    | Ensure JSON syntax in request body is correct.                   | | 401  | Unauthorized      | User doesn't have permission to an API call.                                                | Ensure your SDK key is good.                                     | | 403  | Forbidden         | User does not have permission for operation.                                                | Ensure that the user or access token has proper permissions set. | | 409  | Conflict          | The API request could not be completed because it conflicted with a concurrent API request. | Retry your request.                                              | | 429  | Too many requests | See [Rate limiting](/#section/Rate-limiting).                                               | Wait and try again later.                                        |  # CORS  The LaunchDarkly API supports Cross Origin Resource Sharing (CORS) for AJAX requests from any origin. If an `Origin` header is given in a request, it will be echoed as an explicitly allowed origin. Otherwise, a wildcard is returned: `Access-Control-Allow-Origin: *`. For more information on CORS, see the [CORS W3C Recommendation](http://www.w3.org/TR/cors). Example CORS headers might look like:  ```http Access-Control-Allow-Headers: Accept, Content-Type, Content-Length, Accept-Encoding, Authorization Access-Control-Allow-Methods: OPTIONS, GET, DELETE, PATCH Access-Control-Allow-Origin: * Access-Control-Max-Age: 300 ```  You can make authenticated CORS calls just as you would make same-origin calls, using either [token or session-based authentication](#section/Authentication). If you’re using session auth, you should set the `withCredentials` property for your `xhr` request to `true`. You should never expose your access tokens to untrusted users.  # Rate limiting  We use several rate limiting strategies to ensure the availability of our APIs. Rate-limited calls to our APIs will return a `429` status code. Calls to our APIs will include headers indicating the current rate limit status. The specific headers returned depend on the API route being called. The limits differ based on the route, authentication mechanism, and other factors. Routes that are not rate limited may not contain any of the headers described below.  > ### Rate limiting and SDKs > > LaunchDarkly SDKs are never rate limited and do not use the API endpoints defined here. LaunchDarkly uses a different set of approaches, including streaming/server-sent events and a global CDN, to ensure availability to the routes used by LaunchDarkly SDKs. > > The client-side ID is safe to embed in untrusted contexts. It's designed for use in client-side JavaScript.  ## Global rate limits  Authenticated requests are subject to a global limit. This is the maximum number of calls that can be made to the API per ten seconds. All personal access tokens on the account share this limit, so exceeding the limit with one access token will impact other tokens. Calls that are subject to global rate limits will return the headers below:  | Header name                    | Description                                                                      | | ------------------------------ | -------------------------------------------------------------------------------- | | `X-Ratelimit-Global-Remaining` | The maximum number of requests the account is permitted to make per ten seconds. | | `X-Ratelimit-Reset`            | The time at which the current rate limit window resets in epoch milliseconds.    |  We do not publicly document the specific number of calls that can be made globally. This limit may change, and we encourage clients to program against the specification, relying on the two headers defined above, rather than hardcoding to the current limit.  ## Route-level rate limits  Some authenticated routes have custom rate limits. These also reset every ten seconds. Any access tokens hitting the same route share this limit, so exceeding the limit with one access token may impact other tokens. Calls that are subject to route-level rate limits will return the headers below:  | Header name                   | Description                                                                                           | | ----------------------------- | ----------------------------------------------------------------------------------------------------- | | `X-Ratelimit-Route-Remaining` | The maximum number of requests to the current route the account is permitted to make per ten seconds. | | `X-Ratelimit-Reset`           | The time at which the current rate limit window resets in epoch milliseconds.                         |  A _route_ represents a specific URL pattern and verb. For example, the [Delete environment](/tag/Environments#operation/deleteEnvironment) endpoint is considered a single route, and each call to delete an environment counts against your route-level rate limit for that route.  We do not publicly document the specific number of calls that can be made to each endpoint per ten seconds. These limits may change, and we encourage clients to program against the specification, relying on the two headers defined above, rather than hardcoding to the current limits.  ## IP-based rate limiting  We also employ IP-based rate limiting on some API routes. If you hit an IP-based rate limit, your API response will include a `Retry-After` header indicating how long to wait before re-trying the call. Clients must wait at least `Retry-After` seconds before making additional calls to our API, and should employ jitter and backoff strategies to avoid triggering rate limits again.  # OpenAPI (Swagger)  We have a [complete OpenAPI (Swagger) specification](https://app.launchdarkly.com/api/v2/openapi.json) for our API.  You can use this specification to generate client libraries to interact with our REST API in your language of choice.  This specification is supported by several API-based tools such as Postman and Insomnia. In many cases, you can directly import our specification to ease use in navigating the APIs in the tooling.  # Client libraries  We auto-generate multiple client libraries based on our OpenAPI specification. To learn more, visit [GitHub](https://github.com/search?q=topic%3Alaunchdarkly-api+org%3Alaunchdarkly&type=Repositories).  # Method Overriding  Some firewalls and HTTP clients restrict the use of verbs other than `GET` and `POST`. In those environments, our API endpoints that use `PUT`, `PATCH`, and `DELETE` verbs will be inaccessible.  To avoid this issue, our API supports the `X-HTTP-Method-Override` header, allowing clients to \"tunnel\" `PUT`, `PATCH`, and `DELETE` requests via a `POST` request.  For example, if you wish to call one of our `PATCH` resources via a `POST` request, you can include `X-HTTP-Method-Override:PATCH` as a header.  # Beta resources  We sometimes release new API resources in **beta** status before we release them with general availability.  Resources that are in beta are still undergoing testing and development. They may change without notice, including becoming backwards incompatible.  We try to promote resources into general availability as quickly as possible. This happens after sufficient testing and when we're satisfied that we no longer need to make backwards-incompatible changes.  We mark beta resources with a \"Beta\" callout in our documentation, pictured below:  > ### This feature is in beta > > To use this feature, pass in a header including the `LD-API-Version` key with value set to `beta`. Use this header with each call. To learn more, read [Beta resources](/#section/Beta-resources).  ## Using beta resources  To use a beta resource, you must include a header in the request. If you call a beta resource without this header, you'll receive a `403` response.  Use this header:  ``` LD-API-Version: beta ```  # Versioning  We try hard to keep our REST API backwards compatible, but we occasionally have to make backwards-incompatible changes in the process of shipping new features. These breaking changes can cause unexpected behavior if you don't prepare for them accordingly.  Updates to our REST API include support for the latest features in LaunchDarkly. We also release a new version of our REST API every time we make a breaking change. We provide simultaneous support for multiple API versions so you can migrate from your current API version to a new version at your own pace.  ## Setting the API version per request  You can set the API version on a specific request by sending an `LD-API-Version` header, as shown in the example below:  ``` LD-API-Version: 20191212 ```  The header value is the version number of the API version you'd like to request. The number for each version corresponds to the date the version was released. In the example above the version `20191212` corresponds to December 12, 2019.  ## Setting the API version per access token  When creating an access token, you must specify a specific version of the API to use. This ensures that integrations using this token cannot be broken by version changes.  Tokens created before versioning was released have their version set to `20160426` (the version of the API that existed before versioning) so that they continue working the same way they did before versioning.  If you would like to upgrade your integration to use a new API version, you can explicitly set the header described above.  > ### Best practice: Set the header for every client or integration > > We recommend that you set the API version header explicitly in any client or integration you build. > > Only rely on the access token API version during manual testing. 

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0
- Package version: 6.0.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://support.launchdarkly.com](https://support.launchdarkly.com)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build launchdarkly_api.gemspec
```

Then either install the gem locally:

```shell
gem install ./launchdarkly_api-6.0.0.gem
```
(for development, run `gem install --dev ./launchdarkly_api-6.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'launchdarkly_api', '~> 6.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/launchdarkly/api-client-ruby, then add the following in the Gemfile:

    gem 'launchdarkly_api', :git => 'https://github.com/launchdarkly/api-client-ruby.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and see the [sample code](#sample%20code) below.

## Documentation for API Endpoints

All URIs are relative to *https://app.launchdarkly.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*LaunchDarklyApi::AccessTokensApi* | [**delete_token**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccessTokensApi.md#delete_token) | **DELETE** /api/v2/tokens/{id} | Delete access token
*LaunchDarklyApi::AccessTokensApi* | [**get_token**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccessTokensApi.md#get_token) | **GET** /api/v2/tokens/{id} | Get access token
*LaunchDarklyApi::AccessTokensApi* | [**get_tokens**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccessTokensApi.md#get_tokens) | **GET** /api/v2/tokens | List access tokens
*LaunchDarklyApi::AccessTokensApi* | [**patch_token**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccessTokensApi.md#patch_token) | **PATCH** /api/v2/tokens/{id} | Patch access token
*LaunchDarklyApi::AccessTokensApi* | [**post_token**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccessTokensApi.md#post_token) | **POST** /api/v2/tokens | Create access token
*LaunchDarklyApi::AccessTokensApi* | [**reset_token**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccessTokensApi.md#reset_token) | **POST** /api/v2/tokens/{id}/reset | Reset access token
*LaunchDarklyApi::AccountMembersApi* | [**delete_member**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountMembersApi.md#delete_member) | **DELETE** /api/v2/members/{id} | Delete account member
*LaunchDarklyApi::AccountMembersApi* | [**get_member**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountMembersApi.md#get_member) | **GET** /api/v2/members/{id} | Get account member
*LaunchDarklyApi::AccountMembersApi* | [**get_members**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountMembersApi.md#get_members) | **GET** /api/v2/members | List account members
*LaunchDarklyApi::AccountMembersApi* | [**patch_member**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountMembersApi.md#patch_member) | **PATCH** /api/v2/members/{id} | Modify an account member
*LaunchDarklyApi::AccountMembersApi* | [**post_members**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountMembersApi.md#post_members) | **POST** /api/v2/members | Invite new members
*LaunchDarklyApi::AccountUsageBetaApi* | [**get_evaluations_usage**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountUsageBetaApi.md#get_evaluations_usage) | **GET** /api/v2/usage/evaluations/{projKey}/{envKey}/{flagKey} | Get evaluations usage
*LaunchDarklyApi::AccountUsageBetaApi* | [**get_events_usage**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountUsageBetaApi.md#get_events_usage) | **GET** /api/v2/usage/events/{type} | Get events usage
*LaunchDarklyApi::AccountUsageBetaApi* | [**get_mau_sdks_by_type**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountUsageBetaApi.md#get_mau_sdks_by_type) | **GET** /api/v2/usage/mau/sdks | Get MAU SDKs by type
*LaunchDarklyApi::AccountUsageBetaApi* | [**get_mau_usage**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountUsageBetaApi.md#get_mau_usage) | **GET** /api/v2/usage/mau | Get MAU usage
*LaunchDarklyApi::AccountUsageBetaApi* | [**get_mau_usage_by_category**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountUsageBetaApi.md#get_mau_usage_by_category) | **GET** /api/v2/usage/mau/bycategory | Get MAU usage by category
*LaunchDarklyApi::AccountUsageBetaApi* | [**get_stream_usage**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountUsageBetaApi.md#get_stream_usage) | **GET** /api/v2/usage/streams/{source} | Get stream usage
*LaunchDarklyApi::AccountUsageBetaApi* | [**get_stream_usage_by_sdk_version**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountUsageBetaApi.md#get_stream_usage_by_sdk_version) | **GET** /api/v2/usage/streams/{source}/bysdkversion | Get stream usage by SDK version
*LaunchDarklyApi::AccountUsageBetaApi* | [**get_stream_usage_sdkversion**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccountUsageBetaApi.md#get_stream_usage_sdkversion) | **GET** /api/v2/usage/streams/{source}/sdkversions | Get stream usage SDK versions
*LaunchDarklyApi::ApprovalsApi* | [**delete_approval_request**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ApprovalsApi.md#delete_approval_request) | **DELETE** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/approval-requests/{id} | Delete approval request
*LaunchDarklyApi::ApprovalsApi* | [**get_approval**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ApprovalsApi.md#get_approval) | **GET** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/approval-requests/{id} | Get approval request
*LaunchDarklyApi::ApprovalsApi* | [**get_approvals**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ApprovalsApi.md#get_approvals) | **GET** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/approval-requests | List all approval requests
*LaunchDarklyApi::ApprovalsApi* | [**post_approval_request**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ApprovalsApi.md#post_approval_request) | **POST** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/approval-requests | Create approval request
*LaunchDarklyApi::ApprovalsApi* | [**post_approval_request_apply_request**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ApprovalsApi.md#post_approval_request_apply_request) | **POST** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/approval-requests/{id}/apply | Apply approval request
*LaunchDarklyApi::ApprovalsApi* | [**post_approval_request_review**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ApprovalsApi.md#post_approval_request_review) | **POST** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/approval-requests/{id}/reviews | Review approval request
*LaunchDarklyApi::ApprovalsApi* | [**post_flag_copy_config_approval_request**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ApprovalsApi.md#post_flag_copy_config_approval_request) | **POST** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/copy/environments/{environmentKey}/approval-requests-flag-copy | Create approval request to copy flag configurations across environments
*LaunchDarklyApi::AuditLogApi* | [**get_audit_log_entries**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AuditLogApi.md#get_audit_log_entries) | **GET** /api/v2/auditlog | List audit log feature flag entries
*LaunchDarklyApi::AuditLogApi* | [**get_audit_log_entry**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AuditLogApi.md#get_audit_log_entry) | **GET** /api/v2/auditlog/{id} | Get audit log entry
*LaunchDarklyApi::CodeReferencesApi* | [**delete_branches**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#delete_branches) | **POST** /api/v2/code-refs/repositories/{repo}/branch-delete-tasks | Delete branches
*LaunchDarklyApi::CodeReferencesApi* | [**delete_repository**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#delete_repository) | **DELETE** /api/v2/code-refs/repositories/{repo} | Delete repository
*LaunchDarklyApi::CodeReferencesApi* | [**get_branch**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#get_branch) | **GET** /api/v2/code-refs/repositories/{repo}/branches/{branch} | Get branch
*LaunchDarklyApi::CodeReferencesApi* | [**get_branches**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#get_branches) | **GET** /api/v2/code-refs/repositories/{repo}/branches | List branches
*LaunchDarklyApi::CodeReferencesApi* | [**get_extinctions**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#get_extinctions) | **GET** /api/v2/code-refs/extinctions | List extinctions
*LaunchDarklyApi::CodeReferencesApi* | [**get_repositories**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#get_repositories) | **GET** /api/v2/code-refs/repositories | List repositories
*LaunchDarklyApi::CodeReferencesApi* | [**get_repository**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#get_repository) | **GET** /api/v2/code-refs/repositories/{repo} | Get repository
*LaunchDarklyApi::CodeReferencesApi* | [**get_root_statistic**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#get_root_statistic) | **GET** /api/v2/code-refs/statistics | Get number of code references for flags
*LaunchDarklyApi::CodeReferencesApi* | [**get_statistics**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#get_statistics) | **GET** /api/v2/code-refs/statistics/{projKey} | Get number of code references for flags
*LaunchDarklyApi::CodeReferencesApi* | [**patch_repository**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#patch_repository) | **PATCH** /api/v2/code-refs/repositories/{repo} | Update repository
*LaunchDarklyApi::CodeReferencesApi* | [**post_extinction**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#post_extinction) | **POST** /api/v2/code-refs/repositories/{repo}/branches/{branch} | Create extinction
*LaunchDarklyApi::CodeReferencesApi* | [**post_repository**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#post_repository) | **POST** /api/v2/code-refs/repositories | Create repository
*LaunchDarklyApi::CodeReferencesApi* | [**put_branch**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CodeReferencesApi.md#put_branch) | **PUT** /api/v2/code-refs/repositories/{repo}/branches/{branch} | Upsert branch
*LaunchDarklyApi::CustomRolesApi* | [**delete_custom_role**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CustomRolesApi.md#delete_custom_role) | **DELETE** /api/v2/roles/{key} | Delete custom role
*LaunchDarklyApi::CustomRolesApi* | [**get_custom_role**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CustomRolesApi.md#get_custom_role) | **GET** /api/v2/roles/{key} | Get custom role
*LaunchDarklyApi::CustomRolesApi* | [**get_custom_roles**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CustomRolesApi.md#get_custom_roles) | **GET** /api/v2/roles | List custom roles
*LaunchDarklyApi::CustomRolesApi* | [**patch_custom_role**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CustomRolesApi.md#patch_custom_role) | **PATCH** /api/v2/roles/{key} | Update custom role
*LaunchDarklyApi::CustomRolesApi* | [**post_custom_role**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CustomRolesApi.md#post_custom_role) | **POST** /api/v2/roles | Create custom role
*LaunchDarklyApi::DataExportDestinationsApi* | [**delete_destination**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/DataExportDestinationsApi.md#delete_destination) | **DELETE** /api/v2/destinations/{projKey}/{envKey}/{id} | Delete Data Export destination
*LaunchDarklyApi::DataExportDestinationsApi* | [**get_destination**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/DataExportDestinationsApi.md#get_destination) | **GET** /api/v2/destinations/{projKey}/{envKey}/{id} | Get destination
*LaunchDarklyApi::DataExportDestinationsApi* | [**get_destinations**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/DataExportDestinationsApi.md#get_destinations) | **GET** /api/v2/destinations | List destinations
*LaunchDarklyApi::DataExportDestinationsApi* | [**patch_destination**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/DataExportDestinationsApi.md#patch_destination) | **PATCH** /api/v2/destinations/{projKey}/{envKey}/{id} | Update Data Export destination
*LaunchDarklyApi::DataExportDestinationsApi* | [**post_destination**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/DataExportDestinationsApi.md#post_destination) | **POST** /api/v2/destinations/{projKey}/{envKey} | Create data export destination
*LaunchDarklyApi::EnvironmentsApi* | [**delete_environment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/EnvironmentsApi.md#delete_environment) | **DELETE** /api/v2/projects/{projectKey}/environments/{environmentKey} | Delete environment
*LaunchDarklyApi::EnvironmentsApi* | [**get_environment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/EnvironmentsApi.md#get_environment) | **GET** /api/v2/projects/{projectKey}/environments/{environmentKey} | Get environment
*LaunchDarklyApi::EnvironmentsApi* | [**patch_environment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/EnvironmentsApi.md#patch_environment) | **PATCH** /api/v2/projects/{projectKey}/environments/{environmentKey} | Update environment
*LaunchDarklyApi::EnvironmentsApi* | [**post_environment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/EnvironmentsApi.md#post_environment) | **POST** /api/v2/projects/{projectKey}/environments | Create environment
*LaunchDarklyApi::EnvironmentsApi* | [**reset_environment_mobile_key**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/EnvironmentsApi.md#reset_environment_mobile_key) | **POST** /api/v2/projects/{projectKey}/environments/{envKey}/mobileKey | Reset environment mobile SDK key
*LaunchDarklyApi::EnvironmentsApi* | [**reset_environment_sdk_key**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/EnvironmentsApi.md#reset_environment_sdk_key) | **POST** /api/v2/projects/{projectKey}/environments/{envKey}/apiKey | Reset environment SDK key
*LaunchDarklyApi::ExperimentsBetaApi* | [**get_experiment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentsBetaApi.md#get_experiment) | **GET** /api/v2/flags/{projKey}/{flagKey}/experiments/{envKey}/{metricKey} | Get experiment results
*LaunchDarklyApi::ExperimentsBetaApi* | [**reset_experiment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentsBetaApi.md#reset_experiment) | **DELETE** /api/v2/flags/{projKey}/{flagKey}/experiments/{envKey}/{metricKey}/results | Reset experiment results
*LaunchDarklyApi::FeatureFlagsApi* | [**copy_feature_flag**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#copy_feature_flag) | **POST** /api/v2/flags/{projKey}/{featureFlagKey}/copy | Copy feature flag
*LaunchDarklyApi::FeatureFlagsApi* | [**delete_feature_flag**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#delete_feature_flag) | **DELETE** /api/v2/flags/{projKey}/{key} | Delete feature flag
*LaunchDarklyApi::FeatureFlagsApi* | [**get_expiring_user_targets**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#get_expiring_user_targets) | **GET** /api/v2/flags/{projKey}/{flagKey}/expiring-user-targets/{envKey} | Get expiring user targets for feature flag
*LaunchDarklyApi::FeatureFlagsApi* | [**get_feature_flag**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#get_feature_flag) | **GET** /api/v2/flags/{projKey}/{key} | Get feature flag
*LaunchDarklyApi::FeatureFlagsApi* | [**get_feature_flag_status**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#get_feature_flag_status) | **GET** /api/v2/flag-statuses/{projKey}/{envKey}/{key} | Get feature flag status
*LaunchDarklyApi::FeatureFlagsApi* | [**get_feature_flag_status_across_environments**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#get_feature_flag_status_across_environments) | **GET** /api/v2/flag-status/{projKey}/{key} | Get flag status across environments
*LaunchDarklyApi::FeatureFlagsApi* | [**get_feature_flag_statuses**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#get_feature_flag_statuses) | **GET** /api/v2/flag-statuses/{projKey}/{envKey} | List feature flag statuses
*LaunchDarklyApi::FeatureFlagsApi* | [**get_feature_flags**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#get_feature_flags) | **GET** /api/v2/flags/{projKey} | List feature flags
*LaunchDarklyApi::FeatureFlagsApi* | [**patch_expiring_user_targets**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#patch_expiring_user_targets) | **PATCH** /api/v2/flags/{projKey}/{flagKey}/expiring-user-targets/{envKey} | Update expiring user targets on feature flag
*LaunchDarklyApi::FeatureFlagsApi* | [**patch_feature_flag**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#patch_feature_flag) | **PATCH** /api/v2/flags/{projKey}/{key} | Update feature flag
*LaunchDarklyApi::FeatureFlagsApi* | [**post_feature_flag**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsApi.md#post_feature_flag) | **POST** /api/v2/flags/{projKey} | Create a feature flag
*LaunchDarklyApi::FeatureFlagsBetaApi* | [**get_dependent_flags**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsBetaApi.md#get_dependent_flags) | **GET** /api/v2/flags/{projKey}/{flagKey}/dependent-flags | List dependent feature flags
*LaunchDarklyApi::FeatureFlagsBetaApi* | [**get_dependent_flags_by_env**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagsBetaApi.md#get_dependent_flags_by_env) | **GET** /api/v2/flags/{projKey}/{envKey}/{flagKey}/dependent-flags | List dependent feature flags by environment
*LaunchDarklyApi::MetricsApi* | [**delete_metric**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MetricsApi.md#delete_metric) | **DELETE** /api/v2/metrics/{projectKey}/{key} | Delete metric
*LaunchDarklyApi::MetricsApi* | [**get_metric**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MetricsApi.md#get_metric) | **GET** /api/v2/metrics/{projectKey}/{key} | Get metric
*LaunchDarklyApi::MetricsApi* | [**get_metrics**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MetricsApi.md#get_metrics) | **GET** /api/v2/metrics/{projectKey} | List metrics
*LaunchDarklyApi::MetricsApi* | [**patch_metric**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MetricsApi.md#patch_metric) | **PATCH** /api/v2/metrics/{projectKey}/{key} | Update metric
*LaunchDarklyApi::MetricsApi* | [**post_metric**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MetricsApi.md#post_metric) | **POST** /api/v2/metrics/{projectKey} | Create metric
*LaunchDarklyApi::OtherApi* | [**get_ips**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/OtherApi.md#get_ips) | **GET** /api/v2/public-ip-list | Gets the public IP list
*LaunchDarklyApi::OtherApi* | [**get_openapi_spec**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/OtherApi.md#get_openapi_spec) | **GET** /api/v2/openapi.json | Gets the OpenAPI spec in json
*LaunchDarklyApi::OtherApi* | [**get_root**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/OtherApi.md#get_root) | **GET** /api/v2 | Root resource
*LaunchDarklyApi::OtherApi* | [**get_versions**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/OtherApi.md#get_versions) | **GET** /api/v2/versions | Get version information
*LaunchDarklyApi::ProjectsApi* | [**delete_project**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ProjectsApi.md#delete_project) | **DELETE** /api/v2/projects/{projectKey} | Delete project
*LaunchDarklyApi::ProjectsApi* | [**get_project**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ProjectsApi.md#get_project) | **GET** /api/v2/projects/{projectKey} | Get project
*LaunchDarklyApi::ProjectsApi* | [**get_projects**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ProjectsApi.md#get_projects) | **GET** /api/v2/projects | List projects
*LaunchDarklyApi::ProjectsApi* | [**patch_project**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ProjectsApi.md#patch_project) | **PATCH** /api/v2/projects/{projectKey} | Update project
*LaunchDarklyApi::ProjectsApi* | [**post_project**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ProjectsApi.md#post_project) | **POST** /api/v2/projects | Create project
*LaunchDarklyApi::RelayProxyConfigurationsApi* | [**delete_relay_auto_config**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RelayProxyConfigurationsApi.md#delete_relay_auto_config) | **DELETE** /api/v2/account/relay-auto-configs/{id} | Delete Relay Proxy config by ID
*LaunchDarklyApi::RelayProxyConfigurationsApi* | [**get_relay_proxy_config**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RelayProxyConfigurationsApi.md#get_relay_proxy_config) | **GET** /api/v2/account/relay-auto-configs/{id} | Get Relay Proxy config
*LaunchDarklyApi::RelayProxyConfigurationsApi* | [**get_relay_proxy_configs**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RelayProxyConfigurationsApi.md#get_relay_proxy_configs) | **GET** /api/v2/account/relay-auto-configs | List Relay Proxy configs
*LaunchDarklyApi::RelayProxyConfigurationsApi* | [**patch_relay_auto_config**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RelayProxyConfigurationsApi.md#patch_relay_auto_config) | **PATCH** /api/v2/account/relay-auto-configs/{id} | Update a Relay Proxy config
*LaunchDarklyApi::RelayProxyConfigurationsApi* | [**post_relay_auto_config**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RelayProxyConfigurationsApi.md#post_relay_auto_config) | **POST** /api/v2/account/relay-auto-configs | Create a new Relay Proxy config
*LaunchDarklyApi::RelayProxyConfigurationsApi* | [**reset_relay_auto_config**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RelayProxyConfigurationsApi.md#reset_relay_auto_config) | **POST** /api/v2/account/relay-auto-configs/{id}/reset | Reset Relay Proxy configuration key
*LaunchDarklyApi::ScheduledChangesApi* | [**delete_flag_config_scheduled_changes**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ScheduledChangesApi.md#delete_flag_config_scheduled_changes) | **DELETE** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/scheduled-changes/{id} | Delete scheduled changes workflow
*LaunchDarklyApi::ScheduledChangesApi* | [**get_feature_flag_scheduled_change**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ScheduledChangesApi.md#get_feature_flag_scheduled_change) | **GET** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/scheduled-changes/{id} | Get a scheduled change
*LaunchDarklyApi::ScheduledChangesApi* | [**get_flag_config_scheduled_changes**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ScheduledChangesApi.md#get_flag_config_scheduled_changes) | **GET** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/scheduled-changes | List scheduled changes
*LaunchDarklyApi::ScheduledChangesApi* | [**patch_flag_config_scheduled_change**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ScheduledChangesApi.md#patch_flag_config_scheduled_change) | **PATCH** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/scheduled-changes/{id} | Update scheduled changes workflow
*LaunchDarklyApi::ScheduledChangesApi* | [**post_flag_config_scheduled_changes**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ScheduledChangesApi.md#post_flag_config_scheduled_changes) | **POST** /api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/scheduled-changes | Create scheduled changes workflow
*LaunchDarklyApi::SegmentsApi* | [**delete_segment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentsApi.md#delete_segment) | **DELETE** /api/v2/segments/{projKey}/{envKey}/{key} | Delete segment
*LaunchDarklyApi::SegmentsApi* | [**get_expiring_user_targets_for_segment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentsApi.md#get_expiring_user_targets_for_segment) | **GET** /api/v2/segments/{projKey}/{segmentKey}/expiring-user-targets/{envKey} | Get expiring user targets for segment
*LaunchDarklyApi::SegmentsApi* | [**get_segment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentsApi.md#get_segment) | **GET** /api/v2/segments/{projKey}/{envKey}/{key} | Get segment
*LaunchDarklyApi::SegmentsApi* | [**get_segment_membership_for_user**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentsApi.md#get_segment_membership_for_user) | **GET** /api/v2/segments/{projKey}/{envKey}/{key}/users/{userKey} | Get Big Segment membership for user
*LaunchDarklyApi::SegmentsApi* | [**get_segments**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentsApi.md#get_segments) | **GET** /api/v2/segments/{projKey}/{envKey} | List segments
*LaunchDarklyApi::SegmentsApi* | [**patch_expiring_user_targets_for_segment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentsApi.md#patch_expiring_user_targets_for_segment) | **PATCH** /api/v2/segments/{projKey}/{segmentKey}/expiring-user-targets/{envKey} | Update expiring user targets for segment
*LaunchDarklyApi::SegmentsApi* | [**patch_segment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentsApi.md#patch_segment) | **PATCH** /api/v2/segments/{projKey}/{envKey}/{key} | Patch segment
*LaunchDarklyApi::SegmentsApi* | [**post_segment**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentsApi.md#post_segment) | **POST** /api/v2/segments/{projKey}/{envKey} | Create segment
*LaunchDarklyApi::SegmentsApi* | [**update_big_segment_targets**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentsApi.md#update_big_segment_targets) | **POST** /api/v2/segments/{projKey}/{envKey}/{key}/users | Update targets on a Big Segment
*LaunchDarklyApi::UserSettingsApi* | [**get_expiring_flags_for_user**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserSettingsApi.md#get_expiring_flags_for_user) | **GET** /api/v2/users/{projKey}/{userKey}/expiring-user-targets/{envKey} | Get expiring dates on flags for user
*LaunchDarklyApi::UserSettingsApi* | [**get_user_flag_setting**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserSettingsApi.md#get_user_flag_setting) | **GET** /api/v2/users/{projKey}/{envKey}/{key}/flags/{featureKey} | Get flag setting for user
*LaunchDarklyApi::UserSettingsApi* | [**get_user_flag_settings**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserSettingsApi.md#get_user_flag_settings) | **GET** /api/v2/users/{projKey}/{envKey}/{key}/flags | List flag settings for user
*LaunchDarklyApi::UserSettingsApi* | [**patch_expiring_flags_for_user**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserSettingsApi.md#patch_expiring_flags_for_user) | **PATCH** /api/v2/users/{projKey}/{userKey}/expiring-user-targets/{envKey} | Update expiring user target for flags
*LaunchDarklyApi::UserSettingsApi* | [**put_flag_setting**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserSettingsApi.md#put_flag_setting) | **PUT** /api/v2/users/{projKey}/{envKey}/{key}/flags/{featureKey} | Update flag settings for user
*LaunchDarklyApi::UsersApi* | [**delete_user**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UsersApi.md#delete_user) | **DELETE** /api/v2/users/{projKey}/{envKey}/{key} | Delete user
*LaunchDarklyApi::UsersApi* | [**get_search_users**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UsersApi.md#get_search_users) | **GET** /api/v2/user-search/{projKey}/{envKey} | Find users
*LaunchDarklyApi::UsersApi* | [**get_user**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UsersApi.md#get_user) | **GET** /api/v2/users/{projKey}/{envKey}/{key} | Get user
*LaunchDarklyApi::UsersApi* | [**get_users**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UsersApi.md#get_users) | **GET** /api/v2/users/{projKey}/{envKey} | List users
*LaunchDarklyApi::UsersBetaApi* | [**get_user_attribute_names**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UsersBetaApi.md#get_user_attribute_names) | **GET** /api/v2/user-attributes/{projectKey}/{environmentKey} | Get user attribute names
*LaunchDarklyApi::WebhooksApi* | [**delete_webhook**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/WebhooksApi.md#delete_webhook) | **DELETE** /api/v2/webhooks/{id} | Delete webhook
*LaunchDarklyApi::WebhooksApi* | [**get_all_webhooks**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/WebhooksApi.md#get_all_webhooks) | **GET** /api/v2/webhooks | List webhooks
*LaunchDarklyApi::WebhooksApi* | [**get_webhook**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/WebhooksApi.md#get_webhook) | **GET** /api/v2/webhooks/{id} | Get webhook
*LaunchDarklyApi::WebhooksApi* | [**patch_webhook**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/WebhooksApi.md#patch_webhook) | **PATCH** /api/v2/webhooks/{id} | Update webhook
*LaunchDarklyApi::WebhooksApi* | [**post_webhook**](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/WebhooksApi.md#post_webhook) | **POST** /api/v2/webhooks | Creates a webhook


## Documentation for Models

 - [LaunchDarklyApi::AccessDeniedReasonRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccessDeniedReasonRep.md)
 - [LaunchDarklyApi::AccessDeniedRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccessDeniedRep.md)
 - [LaunchDarklyApi::AccessRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccessRep.md)
 - [LaunchDarklyApi::AccessTokenPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AccessTokenPost.md)
 - [LaunchDarklyApi::ApprovalSettings](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ApprovalSettings.md)
 - [LaunchDarklyApi::AuditLogEntryListingRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AuditLogEntryListingRep.md)
 - [LaunchDarklyApi::AuditLogEntryListingRepCollection](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AuditLogEntryListingRepCollection.md)
 - [LaunchDarklyApi::AuditLogEntryRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AuditLogEntryRep.md)
 - [LaunchDarklyApi::AuthorizedAppDataRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/AuthorizedAppDataRep.md)
 - [LaunchDarklyApi::BigSegmentTarget](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/BigSegmentTarget.md)
 - [LaunchDarklyApi::BranchCollectionRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/BranchCollectionRep.md)
 - [LaunchDarklyApi::BranchRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/BranchRep.md)
 - [LaunchDarklyApi::Clause](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Clause.md)
 - [LaunchDarklyApi::ClientSideAvailability](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ClientSideAvailability.md)
 - [LaunchDarklyApi::ClientSideAvailabilityPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ClientSideAvailabilityPost.md)
 - [LaunchDarklyApi::ConfidenceIntervalRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ConfidenceIntervalRep.md)
 - [LaunchDarklyApi::Conflict](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Conflict.md)
 - [LaunchDarklyApi::CopiedFromEnv](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CopiedFromEnv.md)
 - [LaunchDarklyApi::CreateCopyFlagConfigApprovalRequestRequest](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CreateCopyFlagConfigApprovalRequestRequest.md)
 - [LaunchDarklyApi::CreateFlagConfigApprovalRequestRequest](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CreateFlagConfigApprovalRequestRequest.md)
 - [LaunchDarklyApi::CustomProperty](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CustomProperty.md)
 - [LaunchDarklyApi::CustomRole](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CustomRole.md)
 - [LaunchDarklyApi::CustomRolePost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CustomRolePost.md)
 - [LaunchDarklyApi::CustomRolePostData](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CustomRolePostData.md)
 - [LaunchDarklyApi::CustomRoles](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/CustomRoles.md)
 - [LaunchDarklyApi::DefaultClientSideAvailabilityPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/DefaultClientSideAvailabilityPost.md)
 - [LaunchDarklyApi::Defaults](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Defaults.md)
 - [LaunchDarklyApi::DependentFlag](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/DependentFlag.md)
 - [LaunchDarklyApi::DependentFlagEnvironment](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/DependentFlagEnvironment.md)
 - [LaunchDarklyApi::DependentFlagsByEnvironment](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/DependentFlagsByEnvironment.md)
 - [LaunchDarklyApi::Destination](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Destination.md)
 - [LaunchDarklyApi::DestinationPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/DestinationPost.md)
 - [LaunchDarklyApi::Destinations](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Destinations.md)
 - [LaunchDarklyApi::Environment](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Environment.md)
 - [LaunchDarklyApi::EnvironmentPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/EnvironmentPost.md)
 - [LaunchDarklyApi::ExperimentAllocationRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentAllocationRep.md)
 - [LaunchDarklyApi::ExperimentEnabledPeriodRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentEnabledPeriodRep.md)
 - [LaunchDarklyApi::ExperimentEnvironmentSettingRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentEnvironmentSettingRep.md)
 - [LaunchDarklyApi::ExperimentInfoRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentInfoRep.md)
 - [LaunchDarklyApi::ExperimentMetadataRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentMetadataRep.md)
 - [LaunchDarklyApi::ExperimentRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentRep.md)
 - [LaunchDarklyApi::ExperimentResultsRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentResultsRep.md)
 - [LaunchDarklyApi::ExperimentStatsRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentStatsRep.md)
 - [LaunchDarklyApi::ExperimentTimeSeriesSlice](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentTimeSeriesSlice.md)
 - [LaunchDarklyApi::ExperimentTimeSeriesVariationSlice](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentTimeSeriesVariationSlice.md)
 - [LaunchDarklyApi::ExperimentTotalsRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExperimentTotalsRep.md)
 - [LaunchDarklyApi::ExpiringUserTargetError](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExpiringUserTargetError.md)
 - [LaunchDarklyApi::ExpiringUserTargetGetResponse](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExpiringUserTargetGetResponse.md)
 - [LaunchDarklyApi::ExpiringUserTargetItem](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExpiringUserTargetItem.md)
 - [LaunchDarklyApi::ExpiringUserTargetPatchResponse](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExpiringUserTargetPatchResponse.md)
 - [LaunchDarklyApi::Extinction](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Extinction.md)
 - [LaunchDarklyApi::ExtinctionCollectionRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExtinctionCollectionRep.md)
 - [LaunchDarklyApi::ExtinctionRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ExtinctionRep.md)
 - [LaunchDarklyApi::FeatureFlag](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlag.md)
 - [LaunchDarklyApi::FeatureFlagBody](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagBody.md)
 - [LaunchDarklyApi::FeatureFlagConfig](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagConfig.md)
 - [LaunchDarklyApi::FeatureFlagScheduledChange](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagScheduledChange.md)
 - [LaunchDarklyApi::FeatureFlagScheduledChanges](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagScheduledChanges.md)
 - [LaunchDarklyApi::FeatureFlagStatus](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagStatus.md)
 - [LaunchDarklyApi::FeatureFlagStatusAcrossEnvironments](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagStatusAcrossEnvironments.md)
 - [LaunchDarklyApi::FeatureFlagStatuses](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlagStatuses.md)
 - [LaunchDarklyApi::FeatureFlags](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FeatureFlags.md)
 - [LaunchDarklyApi::FlagConfigApprovalRequestResponse](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FlagConfigApprovalRequestResponse.md)
 - [LaunchDarklyApi::FlagConfigApprovalRequestsResponse](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FlagConfigApprovalRequestsResponse.md)
 - [LaunchDarklyApi::FlagCopyConfigEnvironment](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FlagCopyConfigEnvironment.md)
 - [LaunchDarklyApi::FlagCopyConfigPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FlagCopyConfigPost.md)
 - [LaunchDarklyApi::FlagGlobalAttributesRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FlagGlobalAttributesRep.md)
 - [LaunchDarklyApi::FlagListingRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FlagListingRep.md)
 - [LaunchDarklyApi::FlagScheduledChangesInput](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FlagScheduledChangesInput.md)
 - [LaunchDarklyApi::FlagStatusRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FlagStatusRep.md)
 - [LaunchDarklyApi::FlagSummary](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/FlagSummary.md)
 - [LaunchDarklyApi::HunkRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/HunkRep.md)
 - [LaunchDarklyApi::InlineObject](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/InlineObject.md)
 - [LaunchDarklyApi::InlineObject1](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/InlineObject1.md)
 - [LaunchDarklyApi::InlineResponse200](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/InlineResponse200.md)
 - [LaunchDarklyApi::IntegrationMetadata](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/IntegrationMetadata.md)
 - [LaunchDarklyApi::IntegrationStatus](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/IntegrationStatus.md)
 - [LaunchDarklyApi::IpList](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/IpList.md)
 - [LaunchDarklyApi::LastSeenMetadata](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/LastSeenMetadata.md)
 - [LaunchDarklyApi::Link](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Link.md)
 - [LaunchDarklyApi::Member](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Member.md)
 - [LaunchDarklyApi::MemberDataRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MemberDataRep.md)
 - [LaunchDarklyApi::MemberPermissionGrantSummaryRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MemberPermissionGrantSummaryRep.md)
 - [LaunchDarklyApi::MemberSummaryRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MemberSummaryRep.md)
 - [LaunchDarklyApi::MemberTeamSummaryRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MemberTeamSummaryRep.md)
 - [LaunchDarklyApi::Members](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Members.md)
 - [LaunchDarklyApi::MetricCollectionRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MetricCollectionRep.md)
 - [LaunchDarklyApi::MetricListingRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MetricListingRep.md)
 - [LaunchDarklyApi::MetricPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MetricPost.md)
 - [LaunchDarklyApi::MetricRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MetricRep.md)
 - [LaunchDarklyApi::Modification](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Modification.md)
 - [LaunchDarklyApi::MultiEnvironmentDependentFlag](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MultiEnvironmentDependentFlag.md)
 - [LaunchDarklyApi::MultiEnvironmentDependentFlags](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/MultiEnvironmentDependentFlags.md)
 - [LaunchDarklyApi::NewMemberForm](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/NewMemberForm.md)
 - [LaunchDarklyApi::ParentResourceRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ParentResourceRep.md)
 - [LaunchDarklyApi::PatchOperation](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/PatchOperation.md)
 - [LaunchDarklyApi::PatchSegmentInstruction](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/PatchSegmentInstruction.md)
 - [LaunchDarklyApi::PatchSegmentRequest](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/PatchSegmentRequest.md)
 - [LaunchDarklyApi::PatchWithComment](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/PatchWithComment.md)
 - [LaunchDarklyApi::PostApprovalRequestApplyRequest](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/PostApprovalRequestApplyRequest.md)
 - [LaunchDarklyApi::PostApprovalRequestReviewRequest](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/PostApprovalRequestReviewRequest.md)
 - [LaunchDarklyApi::PostFlagScheduledChangesInput](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/PostFlagScheduledChangesInput.md)
 - [LaunchDarklyApi::Prerequisite](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Prerequisite.md)
 - [LaunchDarklyApi::Project](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Project.md)
 - [LaunchDarklyApi::ProjectListingRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ProjectListingRep.md)
 - [LaunchDarklyApi::ProjectPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ProjectPost.md)
 - [LaunchDarklyApi::Projects](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Projects.md)
 - [LaunchDarklyApi::PubNubDetailRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/PubNubDetailRep.md)
 - [LaunchDarklyApi::ReferenceRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ReferenceRep.md)
 - [LaunchDarklyApi::RelayAutoConfigCollectionRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RelayAutoConfigCollectionRep.md)
 - [LaunchDarklyApi::RelayAutoConfigPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RelayAutoConfigPost.md)
 - [LaunchDarklyApi::RelayAutoConfigRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RelayAutoConfigRep.md)
 - [LaunchDarklyApi::RepositoryCollectionRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RepositoryCollectionRep.md)
 - [LaunchDarklyApi::RepositoryPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RepositoryPost.md)
 - [LaunchDarklyApi::RepositoryRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/RepositoryRep.md)
 - [LaunchDarklyApi::ResourceAccess](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ResourceAccess.md)
 - [LaunchDarklyApi::ResourceIDResponse](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ResourceIDResponse.md)
 - [LaunchDarklyApi::ReviewResponse](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ReviewResponse.md)
 - [LaunchDarklyApi::Rollout](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Rollout.md)
 - [LaunchDarklyApi::Rule](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Rule.md)
 - [LaunchDarklyApi::SdkListRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SdkListRep.md)
 - [LaunchDarklyApi::SdkVersionListRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SdkVersionListRep.md)
 - [LaunchDarklyApi::SdkVersionRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SdkVersionRep.md)
 - [LaunchDarklyApi::SegmentBody](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentBody.md)
 - [LaunchDarklyApi::SegmentMetadata](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentMetadata.md)
 - [LaunchDarklyApi::SegmentUserList](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentUserList.md)
 - [LaunchDarklyApi::SegmentUserState](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SegmentUserState.md)
 - [LaunchDarklyApi::SeriesListRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SeriesListRep.md)
 - [LaunchDarklyApi::SourceFlag](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SourceFlag.md)
 - [LaunchDarklyApi::Statement](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Statement.md)
 - [LaunchDarklyApi::StatementPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/StatementPost.md)
 - [LaunchDarklyApi::StatementPostData](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/StatementPostData.md)
 - [LaunchDarklyApi::StatementRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/StatementRep.md)
 - [LaunchDarklyApi::StatisticCollectionRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/StatisticCollectionRep.md)
 - [LaunchDarklyApi::StatisticRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/StatisticRep.md)
 - [LaunchDarklyApi::StatisticsRoot](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/StatisticsRoot.md)
 - [LaunchDarklyApi::SubjectDataRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/SubjectDataRep.md)
 - [LaunchDarklyApi::Target](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Target.md)
 - [LaunchDarklyApi::TargetResourceRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/TargetResourceRep.md)
 - [LaunchDarklyApi::TitleRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/TitleRep.md)
 - [LaunchDarklyApi::Token](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Token.md)
 - [LaunchDarklyApi::TokenDataRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/TokenDataRep.md)
 - [LaunchDarklyApi::Tokens](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Tokens.md)
 - [LaunchDarklyApi::UrlPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UrlPost.md)
 - [LaunchDarklyApi::User](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/User.md)
 - [LaunchDarklyApi::UserAttributeNamesRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserAttributeNamesRep.md)
 - [LaunchDarklyApi::UserFlagSetting](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserFlagSetting.md)
 - [LaunchDarklyApi::UserFlagSettings](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserFlagSettings.md)
 - [LaunchDarklyApi::UserRecord](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserRecord.md)
 - [LaunchDarklyApi::UserSegment](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserSegment.md)
 - [LaunchDarklyApi::UserSegmentRule](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserSegmentRule.md)
 - [LaunchDarklyApi::UserSegments](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/UserSegments.md)
 - [LaunchDarklyApi::Users](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Users.md)
 - [LaunchDarklyApi::ValuePut](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/ValuePut.md)
 - [LaunchDarklyApi::Variate](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Variate.md)
 - [LaunchDarklyApi::Variation](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Variation.md)
 - [LaunchDarklyApi::VariationOrRolloutRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/VariationOrRolloutRep.md)
 - [LaunchDarklyApi::VariationSummary](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/VariationSummary.md)
 - [LaunchDarklyApi::VersionsRep](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/VersionsRep.md)
 - [LaunchDarklyApi::Webhook](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Webhook.md)
 - [LaunchDarklyApi::WebhookPost](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/WebhookPost.md)
 - [LaunchDarklyApi::Webhooks](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/Webhooks.md)
 - [LaunchDarklyApi::WeightedVariation](https://github.com/launchdarkly/api-client-ruby/blob/2.0/docs/WeightedVariation.md)

## Sample Code

```ruby
# Load the gem
require 'launchdarkly_api'
require 'launchdarkly_api/models/variate'

# Setup authorization
LaunchDarklyApi.configure do |config|
  config.api_key['ApiKey'] = ENV['LD_API_KEY']
  config.debugging = true
end

api_instance = LaunchDarklyApi::FeatureFlagsApi.new

project_key = "openapi"
flag_key = "test-ruby"

# Create a flag with a json variations
body = LaunchDarklyApi::FeatureFlagBody.new(
  name: "test-ruby",
  key: flag_key,
  variations: [
    LaunchDarklyApi::Variate.new({value: [1,2]}),
    LaunchDarklyApi::Variate.new({value: [3,4]}),
    LaunchDarklyApi::Variate.new({value: [5]}),
  ])

begin
  result = api_instance.post_feature_flag(project_key, body)
  p result
rescue LaunchDarklyApi::ApiError => e
  puts "Exception creating feature flag: #{e}"
end

# Clean up new flag
begin
  result = api_instance.delete_feature_flag(project_key, flag_key)
  p result
rescue LaunchDarklyApi::ApiError => e
  puts "Exception deleting feature flag: #{e}"
end
```
